=== modified file 'loggerhead/apps/__init__.py'
--- loggerhead/apps/__init__.py	2009-02-19 01:24:20 +0000
+++ loggerhead/apps/__init__.py	2009-11-26 03:44:40 +0000
@@ -4,10 +4,15 @@
 
 from paste import urlparser, fileapp
 
+from loggerhead.util import convert_file_errors
+
 static = os.path.join(
     os.path.dirname(os.path.dirname(__file__)), 'static')
 
 static_app = urlparser.make_static(None, static)
 
-favicon_app = fileapp.FileApp(os.path.join(static, 'images', 'favicon.ico'))
-robots_app = fileapp.FileApp(os.path.join(static, 'robots.txt'))
+favicon_app = convert_file_errors(fileapp.FileApp(
+    os.path.join(static, 'images', 'favicon.ico')))
+
+robots_app = convert_file_errors(fileapp.FileApp(
+    os.path.join(static, 'robots.txt')))

=== modified file 'loggerhead/apps/transport.py'
--- loggerhead/apps/transport.py	2009-10-21 14:34:51 +0000
+++ loggerhead/apps/transport.py	2009-11-26 03:20:53 +0000
@@ -29,7 +29,7 @@
 from paste import urlparser
 
 from loggerhead.apps.branch import BranchWSGIApp
-from loggerhead.apps import favicon_app, static_app
+from loggerhead.apps import favicon_app, robots_app, static_app
 from loggerhead.controllers.directory_ui import DirectoryUI
 
 _bools = {
@@ -158,6 +158,8 @@
             return static_app(environ, start_response)
         elif environ['PATH_INFO'] == '/favicon.ico':
             return favicon_app(environ, start_response)
+        elif environ['PATH_INFO'] == '/robots.txt':
+            return robots_app(environ, start_response)
         else:
             transport = get_transport_for_thread(self.base)
             return BranchesFromTransportServer(
@@ -182,6 +184,8 @@
             return static_app(environ, start_response)
         elif path_info == '/favicon.ico':
             return favicon_app(environ, start_response)
+        elif environ['PATH_INFO'] == '/robots.txt':
+            return robots_app(environ, start_response)
         else:
             transport = get_transport_for_thread(self.base)
             # segments starting with ~ are user branches

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2009-10-17 06:35:33 +0000
+++ loggerhead/util.py	2009-11-26 03:44:40 +0000
@@ -587,3 +587,20 @@
             if exit_code != 3:
                 return exit_code
             print '-'*20, 'Restarting', '-'*20
+
+
+def convert_file_errors(application):
+    """WSGI wrapper to convert some file errors to Paste exceptions"""
+    def new_application(environ, start_response):
+        try:
+            return application(environ, start_response)
+        except (IOError, OSError), e:
+            import errno
+            from paste import httpexceptions
+            if e.errno == errno.ENOENT:
+                raise httpexceptions.HTTPNotFound()
+            elif e.errno == errno.EACCES:
+                raise httpexceptions.HTTPForbidden()
+            else:
+                raise
+    return new_application

